import { BindingEventService } from '@slickgrid-universal/binding';
import { VanillaCalendar, type IOptions } from 'vanilla-calendar-picker';
import type { Column, ColumnEditor, CompositeEditorOption, Editor, EditorArguments, EditorValidator, EditorValidationResult, GridOption, VanillaCalendarOption } from './../interfaces/index';
import type { TranslaterService } from '../services/translater.service';
import { type SlickGrid } from '../core/index';
export declare class DateEditor implements Editor {
    protected readonly args: EditorArguments;
    protected _bindEventService: BindingEventService;
    protected _clearButtonElm: HTMLButtonElement;
    protected _editorInputGroupElm: HTMLDivElement;
    protected _inputElm: HTMLInputElement;
    protected _isValueTouched: boolean;
    protected _lastClickIsDate: boolean;
    protected _lastTriggeredByClearDate: boolean;
    protected _originalDate?: string;
    protected _pickerMergedOptions: IOptions;
    calendarInstance?: VanillaCalendar;
    defaultDate?: string;
    hasTimePicker: boolean;
    /** is the Editor disabled? */
    disabled: boolean;
    /** SlickGrid Grid object */
    grid: SlickGrid;
    /** Grid options */
    gridOptions: GridOption;
    /** The translate library */
    protected _translaterService: TranslaterService | undefined;
    constructor(args: EditorArguments);
    /** Get Column Definition object */
    get columnDef(): Column;
    /** Get Column Editor object */
    get columnEditor(): ColumnEditor;
    /** Getter for the item data context object */
    get dataContext(): any;
    /** Getter for the Editor DOM Element */
    get editorDomElement(): HTMLInputElement;
    /** Get options passed to the editor by the user */
    get editorOptions(): IOptions;
    get hasAutoCommitEdit(): boolean;
    get pickerOptions(): IOptions;
    /** Get the Validator function, can be passed in Editor property or Column Definition */
    get validator(): EditorValidator | undefined;
    init(): Promise<void>;
    destroy(): void;
    clear(): void;
    disable(isDisabled?: boolean): void;
    /**
     * Dynamically change an Editor option, this is especially useful with Composite Editor
     * since this is the only way to change option after the Editor is created (for example dynamically change "minDate" or another Editor)
     * @param {string} optionName
     * @param {newValue} newValue
     */
    changeEditorOption<T extends keyof VanillaCalendarOption, K extends Partial<VanillaCalendarOption[T]>>(optionName: T, newValue: K): void;
    focus(): void;
    hide(): void;
    show(): void;
    getValue(): string;
    setValue(val: string, isApplyingValue?: boolean, triggerOnCompositeEditorChange?: boolean): void;
    applyValue(item: any, state: any): void;
    isValueChanged(): boolean;
    isValueTouched(): boolean;
    loadValue(item: any): void;
    /**
     * You can reset or clear the input value,
     * when no value is provided it will use the original value to reset (could be useful with Composite Editor Modal with edit/clone)
     */
    reset(value?: string, triggerCompositeEventWhenExist?: boolean, clearByDisableCommand?: boolean): void;
    save(): void;
    serializeValue(): string;
    validate(_targetElm?: any, inputValue?: any): EditorValidationResult;
    /** when it's a Composite Editor, we'll check if the Editor is editable (by checking onBeforeEditCell) and if not Editable we'll disable the Editor */
    protected applyInputUsabilityState(): void;
    protected handleOnDateChange(): void;
    protected handleChangeOnCompositeEditor(compositeEditorOptions: CompositeEditorOption, triggeredBy?: 'user' | 'system', isCalledByClearValue?: boolean): void;
}
//# sourceMappingURL=dateEditor.d.ts.map